@@ -47,6 +47,7 @@ const WindowListPrefsWidget = new GObject.Class({
 
         let modeLabels = {
             'never': _("Never group windows"),
+            'auto': _("Group windows when space is limited"),
             'always': _("Always group windows")
         };
 
@@ -59,9 +60,9 @@ const WindowListPrefsWidget = new GObject.Class({
                continue;
             }
 
-            radio = new Gtk.RadioButton({ group: radio,
+            radio = new Gtk.RadioButton({ active: currentMode == mode,
                                           label: label,
-                                          active: currentMode == mode });
+                                          group: radio });
             grid.add(radio);
 
             radio.connect('toggled', Lang.bind(this, function(button) {
